//----------------------------------------------------------------------------
//  Project Flash
//  owlnext
//  (C) 2008 Sebastian Ledesma
//
//  SUBSYSTEM:    Flash Application
//  FILE:         flshdlgc.cpp
//  AUTHOR:       Sebastian Ledesma
//
//  OVERVIEW
//  ~~~~~~~~
//  Source file for implementation of TFlashDlgClient (TDialog).
//
//----------------------------------------------------------------------------

#include <owl/pch.h>
#include <owl/opensave.h>

#include "flashapp.h"
#include "flshdlgc.h"


//
// Build a response table for all messages/commands handled by the application.
//
DEFINE_RESPONSE_TABLE1(TFlashDlgClient, TOleDialog)
//{{TFlashDlgClientRSP_TBL_BEGIN}}
  EV_WM_SIZE,
  EV_BN_CLICKED(IDC_OPEN, OnOpen),
  EV_BN_CLICKED(IDC_PLAY, OnPlay),
  EV_BN_CLICKED(IDC_STOP, OnStop),
//{{TFlashDlgClientRSP_TBL_END}}
END_RESPONSE_TABLE;


//{{TFlashDlgClient Implementation}}
//static TFlashDlgClientXfer TFlashDlgClientData;

//--------------------------------------------------------
// TFlashDlgClient
// ~~~~~~~~~~
// Construction/Destruction handling.
//
TFlashDlgClient::TFlashDlgClient(TWindow* parent, TResId resId, TModule* module)
:   TOleDialog(parent, resId, module)
{
  // INSERT>> Your constructor code here.
//{{TFlashDlgClientXFER_USE}}
  pBtn_Open = new TButton(this, IDC_OPEN);
  pBtn_Play = new TButton(this, IDC_PLAY);
  pBtn_Stop = new TButton(this, IDC_STOP);
  pBtn_Ok = new TButton(this, IDOK);

//  SetTransferBuffer(&TFlashDlgClientData);
//{{TFlashDlgClientXFER_USE_END}}
	Ocx=NULL;
}


TFlashDlgClient::~TFlashDlgClient() {
	//Destroy(); No need to call, it's already called in TOleDialog destructor

  // INSERT>> Your destructor code here.
}

void TFlashDlgClient::SetupWindow()
{
  TOleDialog::SetupWindow();

  // INSERT>> Your code here.
	GUID  guidFlash = CLSID_NULL;

#define USE_PROGID_TO_OBTAIN_GUID 1
#if USE_PROGID_TO_OBTAIN_GUID
	CLSIDFromProgID(TString("ShockwaveFlash.ShockwaveFlash.1"), &guidFlash);
	if (guidFlash==CLSID_NULL)
   	MessageBox("Shockwave flash not installed in this system","Error",MB_OK);
#else
   guidFlash=CLSID_ShockwaveFlash;
#endif
	Ocx = GetOcControlOfOCX(guidFlash, IDC_SHOCKWAVEFLASH1);
	if (!Ocx) {
		MessageBox("Can't find to OCX control using GUID and control ID, switch to GUID only mode", "Warning", MB_OK);
		Ocx = GetOcControlOfOCX(guidFlash);
	}

	if (Ocx)
		Proxy.Bind(Ocx->GetCtlDispatch());
	else
   	MessageBox("Can't bind to OCX control.\r\nFlash Player not correctly installed?", "Error", MB_OK);

   //Resize the main window (TOleFrame) to the dialog client
	TRect drect;
	TRect srect;
	GetWindowRect(drect);
	AdjustWindowRectEx(drect, Parent->GetStyle(), false, Parent->GetExStyle());
	Parent->SetWindowPos(0, drect, SWP_NOMOVE|SWP_NOZORDER|SWP_SHOWWINDOW);

	if (Ocx) { //We cannot use SetWindowPos on a OcControl
      Ocx->SetTop(14);	//use specific API
      Ocx->SetLeft(0);
		//  Proxy.SetMovie("owl.swf");
   }
}


void TFlashDlgClient::CleanupWindow()
{
	/*if (Ocx) { //Use CanClose !
		Proxy.Unbind();
	} */
	TOleDialog::CleanupWindow();

  // INSERT>> Your code here.
}


void TFlashDlgClient::EvSize(uint sizeType, TSize& size)
{
    TOleDialog::EvSize(sizeType, size);

  // INSERT>> Your code here.
	if (sizeType != SIZEICONIC ) {
	  	if (Ocx) {
  			//Ocx->SetWindowPos(0, 0, 14, size.cx, size.cy-40-10, SWP_NOZORDER | SWP_NOMOVE);
      	Ocx->SetWidth(size.cx);
	      Ocx->SetHeight(size.cy-40-10);
      }

		pBtn_Open->SetWindowPos(0, 10, size.cy-30, 0, 0, SWP_NOZORDER | SWP_NOSIZE);
		pBtn_Play->SetWindowPos(0, 100, size.cy-30, 0, 0, SWP_NOZORDER | SWP_NOSIZE);
		pBtn_Stop->SetWindowPos(0, 190, size.cy-30, 0, 0, SWP_NOZORDER | SWP_NOSIZE);
		pBtn_Ok->SetWindowPos(0, 280, size.cy-30, 0, 0, SWP_NOZORDER | SWP_NOSIZE);
	}

}


void TFlashDlgClient::OnOpen() {
  // INSERT>> Your code here.
  char filename[MAX_PATH];
  TFileOpenDialog::TData FilenameData (OFN_FILEMUSTEXIST | OFN_PATHMUSTEXIST | OFN_NOCHANGEDIR,
	    "Shockwave flash files (*.swf)|*.swf|", 0, filename, 0, 0 /*4096*/);
  if (TFileOpenDialog(this, FilenameData).Execute() != IDOK)
			return;

  //TBSTR bstrFilename;     //defined in <ocf/oleutil.h>
  //TSysStr sysStrFilename; //defined in <winsys/string.h>

//  wchar_t wFilename[MAX_PATH];
//  MultiByteToWideChar(CP_ACP, MB_PRECOMPOSED, FilenameData.FileName, -1, wFilename, MAX_PATH);
//  BSTR  bstrFilename=::SysAllocString(wFilename);
//  Proxy.SetMovie(bstrFilename);
//  ::SysFreeString(bstrFilename);
  Proxy.SetMovie(FilenameData.FileName); //Thanks TAutoString! 
}


void TFlashDlgClient::OnPlay() {
  // INSERT>> Your code here.
  Proxy.Play();
}


void TFlashDlgClient::OnStop() {
	// INSERT>> Your code here.
//	if (!Proxy.GetPlaying())     //if stoped =>rewind
	if (!Proxy.IsPlaying())     //if stoped =>rewind
		Proxy.Rewind();
	Proxy.Stop();
   //Note: isPlaying and GetPlaying seems to do the same, even they invoke different functions
}


bool TFlashDlgClient::CanClose() {
	if (Ocx) {
		Proxy.Unbind();
      Ocx=NULL;
	}

  bool result;
  result = TOleDialog::CanClose();
  // INSERT>> Your code here.     
  return result;
}

